==> ant_1.9.12.orig.tar.xz: apache-ant-1.9.12/src/tests/junit/org/apache/tools/ant/types/RedirectorElementTest.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
package org.apache.tools.ant.types;

import org.apache.tools.ant.AntAssert;
import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.BuildFileRule;
import org.apache.tools.ant.Project;
import org.junit.Before;
import org.junit.Rule;
import org.junit.Test;

import static org.junit.Assert.assertTrue;
import static org.junit.Assert.fail;

public class RedirectorElementTest {

    @Rule
    public BuildFileRule buildRule = new BuildFileRule();

    @Before
    public void setUp() {
        buildRule.configureProject("src/etc/testcases/types/redirector.xml", Project.MSG_VERBOSE);
    }

    @Test
    public void test1() {
        buildRule.executeTarget("test1");
        assertTrue((buildRule.getProject().<Object> getReference("test1")
            instanceof RedirectorElement));
    }

    @Test
    public void test2() {
        try {
            buildRule.executeTarget("test2");
            fail("You must not specify more than one attribute when using refid");
        } catch (BuildException ex) {
            //TODO assert exception message
        }
    }

    @Test
    public void test3() {
        try {
            buildRule.executeTarget("test3");
            fail("You must not specify nested elements when using refid");
        } catch (BuildException ex) {
            //TODO assert exception message
        }
    }

    @Test
    public void test4() {
        buildRule.executeTarget("test4");
    }

    @Test
    public void testLogInputString() {
        buildRule.executeTarget("testLogInputString");
        if (buildRule.getLog().contains("testLogInputString can-cat")) {
            AntAssert.assertContains("Using input string", buildRule.getFullLog());
        }
    }

    @Test
    public void testRefid() {
        buildRule.executeTarget("testRefid");
    }

}

==> ant_1.10.3.orig.tar.xz: apache-ant-1.10.3/src/tests/junit/org/apache/tools/ant/types/RedirectorElementTest.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
package org.apache.tools.ant.types;

import org.apache.tools.ant.AntAssert;
import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.BuildFileRule;
import org.apache.tools.ant.Project;
import org.junit.Before;
import org.junit.Rule;
import org.junit.Test;

import static org.junit.Assert.assertTrue;
import static org.junit.Assert.fail;

public class RedirectorElementTest {

    @Rule
    public BuildFileRule buildRule = new BuildFileRule();

    @Before
    public void setUp() {
        buildRule.configureProject("src/etc/testcases/types/redirector.xml", Project.MSG_VERBOSE);
    }

    @Test
    public void test1() {
        buildRule.executeTarget("test1");
        assertTrue((buildRule.getProject().<Object> getReference("test1")
            instanceof RedirectorElement));
    }

    @Test
    public void test2() {
        try {
            buildRule.executeTarget("test2");
            fail("You must not specify more than one attribute when using refid");
        } catch (BuildException ex) {
            //TODO assert exception message
        }
    }

    @Test
    public void test3() {
        try {
            buildRule.executeTarget("test3");
            fail("You must not specify nested elements when using refid");
        } catch (BuildException ex) {
            //TODO assert exception message
        }
    }

    @Test
    public void test4() {
        buildRule.executeTarget("test4");
    }

    @Test
    public void testLogInputString() {
        buildRule.executeTarget("testLogInputString");
        if (buildRule.getLog().indexOf("testLogInputString can-cat") >= 0) {
            AntAssert.assertContains("Using input string", buildRule.getFullLog());
        }
    }

    @Test
    public void testRefid() {
        buildRule.executeTarget("testRefid");
    }

}
